import pytest


@pytest.fixture(scope="session")
def Anything():
    return type.__new__(
        type,
        "Anything",
        (object,),
        {
            "__repr__": lambda self: self.__class__.__name__,
            "__eq__": lambda _, __: True,
        },
    )()


@pytest.fixture(scope="session")
def Something():
    return type.__new__(
        type,
        "Something",
        (object,),
        {
            "__repr__": lambda self: self.__class__.__name__,
            "__eq__": lambda _, other: other is not None,
        },
    )()



from setuptools import find_packages, setup, findall


with open("README.rst") as f:
    description = f.read()


entry_points = {"pytest11": ["pytest_anything = pytest_anything"]}

setup_kwargs = {
    "name": "pytest-anything",
    "version": "0.1.0",
    "description": "Pytest fixtures to assert anything and something",
    "long_description": description,
    "long_description_content_type": "text/x-rst",
    "author": "Oliver Berger",
    "author_email": "diefans@gmail.com",
    "url": "https://gitlab.com/diefans/pytest-anything",
    "package_dir": {"": "src"},
    "packages": find_packages("src"),
    # "package_data": {"": ["*"]},
    "install_requires": ["pytest"],
    "extras_require": {"tests": ["pytest>=4.6,<5.0", "pdbpp"]},
    "entry_points": entry_points,
    "python_requires": ">=3.7,<4.0",
    "classifiers": [
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Framework :: AsyncIO",
        "License :: OSI Approved :: Apache Software License",
        "License :: OSI Approved :: MIT License",
    ],
}

setup(**setup_kwargs)
